@@ -78,8 +78,9 @@ class ModuleStatusModel:
     pod = ''
     branch = ''
     msg = ''
+    tag = ''
 
-    def __init__(self, module, pod, res, branch, msg=''):
+    def __init__(self, module, pod, res, branch, msg='', tag=''):
         """
         :param module: 模块名字
         :param pod: pod名字
@@ -92,6 +93,7 @@ class ModuleStatusModel:
         self.pod = pod
         self.msg = msg
         self.branch = branch
+        self.tag = tag
 
 
 # 读取yaml文件数据
@@ -409,6 +411,7 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
     # 获取ymal 数据
     podfile_module_data = yaml_data(yaml_path)
     dependenceList = podfile_module_data["dependencies"]
+    before_branch = podfile_module_data["branch"]
     # 转换成模型数组
     conver_deplist = load_yaml(dependenceList)
 
@@ -416,11 +419,13 @@ def update_module_files(yaml_path, local_yaml_path, branch_result, n_branch, mod
     for a in conver_deplist:
         for mo_re in branch_result:
             if a.module and mo_re.module and a.module == mo_re.module and mo_re.result == 1:
-                module_dict = {"module": mo_re.module, "pod": a.pod, "git": a.git, "configurations": a.configurations,
+                module_dict = {"module": mo_re.module, "pod": a.pod, "git": a.git, "branch": n_branch, "configurations": a.configurations,
                                "inhibit_warnings": a.inhibit_warnings}
                 dependenceList[index] = module_dict
         index += 1
-    podfile_data = {"version": "1.0.0", "branch": str(n_branch), "dependencies": dependenceList}
+    if not (before_branch and len(before_branch) > 0):
+        before_branch = n_branch
+    podfile_data = {"version": "1.0.0", "branch": str(before_branch), "dependencies": dependenceList}
     update_yaml(yaml_path, podfile_data)
 
     after_convert = []
@@ -481,7 +486,7 @@ def merge_for_module_files(yaml_path, branch_result, n_branch):
     for a in conver_deplist:
         for mo_re in branch_result:
             if a.module and mo_re.module and a.module == mo_re.module and mo_re.result == 1:
-                module_dict = {"module": mo_re.module, "pod": a.pod, "git": a.git, "tag": mo_re.tag,
+                module_dict = {"module": a.module, "pod": a.pod, "git": a.git, "tag": mo_re.tag,
                                "configurations": a.configurations,
                                "inhibit_warnings": a.inhibit_warnings}
                 dependenceList[index] = module_dict
@@ -942,7 +947,7 @@ def merge_branch(module_list, convert_list, module_f_path, from_branch):
 
 
 # 基于podfileModule，提交模块开发分支代码
-def release_branch(module_list, tag_path, c_path, f_branch):
+def release_branch(module_list, include_list, tag_path, c_path, f_branch):
     """
     基于模块列表，合并对应开发分支代码到master并打新的tag
     :param module_list: 模块列表
@@ -958,15 +963,17 @@ def release_branch(module_list, tag_path, c_path, f_branch):
         if not (a.branch and len(a.branch) > 0) and not (a.tag and len(a.tag) > 0):
             a.branch = f_branch
         if a.branch and len(a.branch) > 0:
-            filename = get_filename(a.git)
-            module_path = tag_path + filename + "/"
-            create_tag = auto_release_path(module_path, a.git, a.pod, a.branch, a.new_tag)
-            result = 0
-            if create_tag and len(create_tag) > 0:
-                result = 1
-                a.new_tag = create_tag
-            merge_model = ModuleStatusModel(a.module, a.pod, result, a.branch)
-            merge_result.append(merge_model)
+            if (len(include_list) > 0 and a.module in include_list) or len(include_list) == 0:
+                filename = get_filename(a.git)
+                module_path = tag_path + filename + "/"
+                create_tag = auto_release_path(module_path, a.git, a.pod, a.branch, a.new_tag)
+                result = 0
+                if create_tag and len(create_tag) > 0:
+                    result = 1
+                    a.new_tag = create_tag
+                merge_model = ModuleStatusModel(a.module, a.pod, result, a.branch, tag=create_tag)
+                merge_result.append(merge_model)
+
         index += 1
         os.chdir(c_path)
     return merge_result
@@ -1036,7 +1043,7 @@ class yhgit:
         1. 如果本地有该组件的目录，就跳过，不会切换到新分支（避免造成，手动切换分之后，又自定切换到新分支）
         2. 如果本地没有改组件目录，就新建目录，拉取master下tag的代码，然后创建新分支
         :param n_branch: 新分支的名字
-        :param module_list: 拉取这些模块，并创建新分支。
+        :param modules: 拉取这些模块，并创建新分支。
         :return:
         """
         c_path = os.getcwd()
@@ -1295,13 +1302,13 @@ class yhgit:
             printTable(fail_list, "代码merge失败的模块")
 
     # 自动提交子模块的代码
-    def release(self):
+    def release(self, include_list=[]):
         """
         基于podfileModules的配置信息，merge开发分支到master，获取开发分支的版本号，如果版本号大于master分支，新的tag就为开发分支版本号，如果版本号相等，那那么就末尾自增1，自动打tag
         :return:
         """
         c_path = os.getcwd()
-        fa_path = self.path
+        fa_path = ''
         modules_file_name = "tagpath"
         modules_path = fa_path + modules_file_name + "/"
         # 子目录，用来存放子模块仓库
@@ -1322,7 +1329,7 @@ class yhgit:
         # 转换成模型数组
         conver_deplist = load_yaml(dependenceList)
         logging.info("转换成模型")
-        branch_res = release_branch(conver_deplist, modules_path, c_path, branch)
+        branch_res = release_branch(conver_deplist, include_list, modules_path, c_path, branch)
         if len(branch_res) > 0:
             merge_for_module_files(yamlPath, branch_res, branch)
         if len(branch_res) == 0:
@@ -1438,12 +1445,15 @@ def main(argvs=None):
         yhgit().push()
 
     elif command == "release":
-        yhgit().release()
+        modules = []
+        if len(argvs) > 2:
+            modules = argvs[2:]
+        yhgit().release(modules)
 
     elif command == "clean":
         yhgit().clean()
     elif command == "version":
-        debugInfo("version 2.3")
+        debugInfo("version 2.4")
     elif command == "help" or command == "-h":
 
         """
